@@ -1,17 +1,17 @@
 /*
-   SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "importwizardkernel.h"
 
-#include <KIdentityManagement/kidentitymanagement/identitymanager.h>
-#include <MailCommon/FolderCollectionMonitor>
-#include <AkonadiCore/session.h>
-#include <AkonadiCore/entitytreemodel.h>
-#include <AkonadiCore/entitymimetypefiltermodel.h>
 #include <AkonadiCore/changerecorder.h>
+#include <AkonadiCore/entitymimetypefiltermodel.h>
+#include <AkonadiCore/entitytreemodel.h>
+#include <AkonadiCore/session.h>
+#include <KIdentityManagement/kidentitymanagement/identitymanager.h>
 #include <KSharedConfig>
+#include <MailCommon/FolderCollectionMonitor>
 
 ImportWizardKernel::ImportWizardKernel(QObject *parent)
     : QObject(parent)
@@ -104,11 +104,11 @@ Akonadi::Collection::Id ImportWizardKernel::lastSelectedFolder()
 
 void ImportWizardKernel::setLastSelectedFolder(Akonadi::Collection::Id col)
 {
-    Q_UNUSED(col);
+    Q_UNUSED(col)
 }
 
 void ImportWizardKernel::expunge(Akonadi::Collection::Id col, bool sync)
 {
-    Q_UNUSED(col);
-    Q_UNUSED(sync);
+    Q_UNUSED(col)
+    Q_UNUSED(sync)
 }
